import json
import os
from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class Sol(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/licencing-service/licence', handler=self.license)]

    async def license(self, request: web.Request) -> web.Response:
        body = await request.json()

        keys = []
        if 'hasp' in body:
            keys.append(body['hasp'])
        if 'frs' in body:
            keys.extend(body['frs'])
        keys.append(body['hw'])

        self.log.info(f"Поиск лицензии для ключей {keys}")
        for key in keys:
            if self._hasCases(request.path, key):
                response = self._createResponse(request.path, key)
                data = json.loads(response.text)
                if 'licence' in data and data['licence'] is not None:
                    path = os.path.join(self.serviceDir, 'license', data['licence'])
                    if os.path.isfile(path):
                        with open(path, 'r') as file:
                            data['licence'] = file.read()
                        response.text = json.dumps(data)
                return response

        raise web.HTTPInternalServerError(text='Нет результата ни для одного из ключей')

instance = Sol()
